<?php
/**
 * Featured Section options
 *
 * @package Theme Palace
 * @subpackage Tale Travel Pro
 * @since Tale Travel Pro 1.0.0
 */

// Add Featured section
$wp_customize->add_section( 'tale_travel_pro_featured_section', array(
	'title'             => esc_html__( 'Featured','tale-travel-pro' ),
	'description'       => esc_html__( 'Featured Section options.', 'tale-travel-pro' ),
	'panel'             => 'tale_travel_pro_front_page_panel',
) );

// Featured content enable control and setting
$wp_customize->add_setting( 'tale_travel_pro_theme_options[featured_section_enable]', array(
	'default'			=> 	$options['featured_section_enable'],
	'sanitize_callback' => 'tale_travel_pro_sanitize_switch_control',
) );

$wp_customize->add_control( new Tale_Travel_Pro_Switch_Control( $wp_customize, 'tale_travel_pro_theme_options[featured_section_enable]', array(
	'label'             => esc_html__( 'Featured Section Enable', 'tale-travel-pro' ),
	'section'           => 'tale_travel_pro_featured_section',
	'on_off_label' 		=> tale_travel_pro_switch_options(),
) ) );

// Featured content type control and setting
$wp_customize->add_setting( 'tale_travel_pro_theme_options[featured_content_type]', array(
	'default'          	=> $options['featured_content_type'],
	'sanitize_callback' => 'tale_travel_pro_sanitize_select',
) );

$wp_customize->add_control( 'tale_travel_pro_theme_options[featured_content_type]', array(
	'label'             => esc_html__( 'Content Type', 'tale-travel-pro' ),
	'section'           => 'tale_travel_pro_featured_section',
	'type'				=> 'select',
	'active_callback' 	=> 'tale_travel_pro_is_featured_section_enable',
	'choices'			=> tale_travel_pro_featured_content_type(),
) );

for ( $i=1; $i <= 3; $i++ ) { 
	// featured pages drop down chooser control and setting
	$wp_customize->add_setting( 'tale_travel_pro_theme_options[featured_content_page_' . $i . ']', array(
		'sanitize_callback' => 'tale_travel_pro_sanitize_page',
	) );

	$wp_customize->add_control( new Tale_Travel_Pro_Dropdown_Chooser( $wp_customize, 'tale_travel_pro_theme_options[featured_content_page_' . $i . ']', array(
		'label'             => sprintf ( esc_html__( 'Select Page %d', 'tale-travel-pro' ), $i ),
		'section'           => 'tale_travel_pro_featured_section',
		'choices'			=> tale_travel_pro_page_choices(),
		'active_callback'	=> 'tale_travel_pro_is_featured_section_content_page_enable',
	) ) );

	// featured posts drop down chooser control and setting
	$wp_customize->add_setting( 'tale_travel_pro_theme_options[featured_content_post_' . $i . ']', array(
		'sanitize_callback' => 'tale_travel_pro_sanitize_page',
	) );

	$wp_customize->add_control( new Tale_Travel_Pro_Dropdown_Chooser( $wp_customize, 'tale_travel_pro_theme_options[featured_content_post_' . $i . ']', array(
		'label'             => sprintf ( esc_html__( 'Select posts %d', 'tale-travel-pro' ), $i ),
		'section'           => 'tale_travel_pro_featured_section',
		'choices'			=> tale_travel_pro_post_choices(),
		'active_callback'	=> 'tale_travel_pro_is_featured_section_content_post_enable',
	) ) );

	// featured trips drop down chooser control and setting
	$wp_customize->add_setting( 'tale_travel_pro_theme_options[featured_content_trip_' . $i . ']', array(
		'sanitize_callback' => 'tale_travel_pro_sanitize_page',
	) );

	$wp_customize->add_control( new Tale_Travel_Pro_Dropdown_Chooser( $wp_customize, 'tale_travel_pro_theme_options[featured_content_trip_' . $i . ']', array(
		'label'             => sprintf ( esc_html__( 'Select Trip %d', 'tale-travel-pro' ), $i ),
		'section'           => 'tale_travel_pro_featured_section',
		'choices'			=> tale_travel_pro_trip_choices(),
		'active_callback'	=> 'tale_travel_pro_is_featured_section_content_trip_enable',
	) ) );
}

// Add dropdown category setting and control.
$wp_customize->add_setting(  'tale_travel_pro_theme_options[featured_content_category]', array(
	'sanitize_callback' => 'tale_travel_pro_sanitize_single_category',
) ) ;

$wp_customize->add_control( new Tale_Travel_Pro_Dropdown_Taxonomies_Control( $wp_customize,'tale_travel_pro_theme_options[featured_content_category]', array(
	'label'             => esc_html__( 'Select Category', 'tale-travel-pro' ),
	'description'      	=> esc_html__( 'Note: Latest selected no of posts will be shown from selected category', 'tale-travel-pro' ),
	'section'           => 'tale_travel_pro_featured_section',
	'type'              => 'dropdown-taxonomies',
	'active_callback'	=> 'tale_travel_pro_is_featured_section_content_category_enable'
) ) );

// Add dropdown category setting and control.
$wp_customize->add_setting(  'tale_travel_pro_theme_options[featured_content_trip_types]', array(
	'sanitize_callback' => 'absint',
) ) ;

$wp_customize->add_control( new Tale_Travel_Pro_Dropdown_Taxonomies_Control( $wp_customize,'tale_travel_pro_theme_options[featured_content_trip_types]', array(
	'label'             => esc_html__( 'Select Trip Types', 'tale-travel-pro' ),
	'section'           => 'tale_travel_pro_featured_section',
	'taxonomy'			=> 'itinerary_types',
	'type'              => 'dropdown-taxonomies',
	'active_callback'	=> 'tale_travel_pro_is_featured_section_content_trip_types_enable'
) ) );

// Add dropdown category setting and control.
$wp_customize->add_setting(  'tale_travel_pro_theme_options[featured_content_activity]', array(
	'sanitize_callback' => 'absint',
) ) ;

$wp_customize->add_control( new Tale_Travel_Pro_Dropdown_Taxonomies_Control( $wp_customize,'tale_travel_pro_theme_options[featured_content_activity]', array(
	'label'             => esc_html__( 'Select Activities', 'tale-travel-pro' ),
	'section'           => 'tale_travel_pro_featured_section',
	'taxonomy'			=> 'activity',
	'type'              => 'dropdown-taxonomies',
	'active_callback'	=> 'tale_travel_pro_is_featured_section_content_activity_enable'
) ) );

// Add dropdown category setting and control.
$wp_customize->add_setting(  'tale_travel_pro_theme_options[featured_content_destination]', array(
	'sanitize_callback' => 'absint',
) ) ;

$wp_customize->add_control( new Tale_Travel_Pro_Dropdown_Taxonomies_Control( $wp_customize,'tale_travel_pro_theme_options[featured_content_destination]', array(
	'label'             => esc_html__( 'Select Destinations', 'tale-travel-pro' ),
	'section'           => 'tale_travel_pro_featured_section',
	'taxonomy'			=> 'travel_locations',
	'type'              => 'dropdown-taxonomies',
	'active_callback'	=> 'tale_travel_pro_is_featured_section_content_destination_enable'
) ) );

// Featured subscribe enable control and setting
$wp_customize->add_setting( 'tale_travel_pro_theme_options[featured_subscribe_enable]', array(
	'default'			=> 	$options['featured_subscribe_enable'],
	'sanitize_callback' => 'tale_travel_pro_sanitize_switch_control',
) );

$wp_customize->add_control( new Tale_Travel_Pro_Switch_Control( $wp_customize, 'tale_travel_pro_theme_options[featured_subscribe_enable]', array(
	'label'             => esc_html__( 'Featured Subscription Enable', 'tale-travel-pro' ),
	'description'       => esc_html__( 'Install Jetpack and Enable Subscription Module to activate Subsription form.', 'tale-travel-pro' ),
	'section'           => 'tale_travel_pro_featured_section',
	'active_callback' 	=> 'tale_travel_pro_is_featured_section_enable',
	'on_off_label' 		=> tale_travel_pro_switch_options(),
) ) );

// Featured title setting and control
$wp_customize->add_setting( 'tale_travel_pro_theme_options[featured_subscribe_title]', array(
	'sanitize_callback' => 'sanitize_text_field',
	'default'			=> $options['featured_subscribe_title'],
) );

$wp_customize->add_control( 'tale_travel_pro_theme_options[featured_subscribe_title]', array(
	'label'           	=> esc_html__( 'Subscription Title', 'tale-travel-pro' ),
	'section'        	=> 'tale_travel_pro_featured_section',
	'active_callback' 	=> 'tale_travel_pro_is_featured_section_subscribe_enable',
	'type'				=> 'text',
) );

// Featured btn title setting and control
$wp_customize->add_setting( 'tale_travel_pro_theme_options[featured_subscribe_btn_title]', array(
	'sanitize_callback' => 'sanitize_text_field',
	'default'			=> $options['featured_subscribe_btn_title'],
) );

$wp_customize->add_control( 'tale_travel_pro_theme_options[featured_subscribe_btn_title]', array(
	'label'           	=> esc_html__( 'Subscription Button Title', 'tale-travel-pro' ),
	'section'        	=> 'tale_travel_pro_featured_section',
	'active_callback' 	=> 'tale_travel_pro_is_featured_section_subscribe_enable',
	'type'				=> 'text',
) );

// Featured image setting and control.
$wp_customize->add_setting( 'tale_travel_pro_theme_options[featured_subscribe_image]', array(
	'sanitize_callback' => 'tale_travel_pro_sanitize_image'
) );

$wp_customize->add_control( new WP_Customize_Image_Control( $wp_customize, 'tale_travel_pro_theme_options[featured_subscribe_image]',
		array(
		'label'       		=> esc_html__( 'Subscription Image', 'tale-travel-pro' ),
		'description' 		=> sprintf( esc_html__( 'Recommended size: %1$dpx x %2$dpx ', 'tale-travel-pro' ), 500, 500 ),
		'section'     		=> 'tale_travel_pro_featured_section',
		'active_callback'	=> 'tale_travel_pro_is_featured_section_subscribe_enable',
) ) );